===============================================================
``psyclone.domain.nemo.transformations.create_nemo_loop_trans``
===============================================================

.. automodule:: psyclone.domain.nemo.transformations.create_nemo_loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.create_nemo_loop_trans


Classes
=======

- :py:class:`CreateNemoLoopTrans`:
  Transform a generic PSyIR Loop into a NemoLoop. For example:


.. autoclass:: CreateNemoLoopTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: CreateNemoLoopTrans
      :parts: 1
